﻿<?xml version="1.0"?>
<!DOCTYPE data-sheet SYSTEM "data-sheet-en.dtd">

<xsl:stylesheet version="1.0"
      xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
      xmlns:fo="http://www.w3.org/1999/XSL/Format">
   <xsl:output method="xml"/>

<!-- XSL 2.0 only
     Use this to map U+2011 to U+002D
     When we have an XSL 2.0 processor, edit the .xml files to change all &nbhy; entities back to U+2011.
     We can also use this to do special processing of © and ® symbols.

   <xsl:output method="xml"/ use-character-maps="basic">
   <xsl:character-map name="basic">
      <xsl:output-character character="&#x2011;" string="-"/>
   </xsl:character-map>

-->

  <xsl:param name="paper-size" select="'letter'"/>

  <!-- A4 = 297.0mm x 210.0mm + 6.00mm cut area = 303.00mm x 216.00mm -->
  <!-- US = 279.4mm x 215.9mm + 6.35mm cut area = 285.75mm x 222.25mm -->
  <!-- US =  11.0in x   8.5in + 0.25in cut area =  11.25in x   8.75in -->
  <xsl:variable name="page-height-mm" select="($paper-size = 'letter') * 285.75 + ($paper-size = 'A4') * 303.00"/>
  <xsl:variable name="page-width-mm"  select="($paper-size = 'letter') * 222.25 + ($paper-size = 'A4') * 216.00"/>

  <xsl:variable name="margin-left-mm"  select="(0.08 * $page-width-mm)"/>
  <xsl:variable name="margin-right-mm" select="(0.07 * $page-width-mm)"/>
  <xsl:variable name="column-gap-mm"   select="(0.05 * $page-width-mm)"/>

  <xsl:variable name="margin-left"   select="format-number($margin-left-mm,  '0.00mm')"/>
  <xsl:variable name="margin-right"  select="format-number($margin-right-mm, '0.00mm')"/>

  <xsl:variable name="basis-blue"  select="'rgb(  8, 74,135)'"/>
  <xsl:variable name="basis-green" select="'rgb(196,222,135)'"/>

  <xsl:attribute-set name="page-layout">
     <xsl:attribute name="page-height"><xsl:value-of select="format-number($page-height-mm, '0.00mm')"/></xsl:attribute>
     <xsl:attribute name="page-width" ><xsl:value-of select="format-number($page-width-mm,  '0.00mm')"/></xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="body-layout">
     <xsl:attribute name="margin-left" ><xsl:value-of select="$margin-left" /></xsl:attribute>
     <xsl:attribute name="margin-right"><xsl:value-of select="$margin-right"/></xsl:attribute>
     <xsl:attribute name="column-gap"><xsl:value-of select="format-number($column-gap-mm, '0.00mm')"/></xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Title">
     <xsl:attribute name="margin-left">23pt</xsl:attribute>
     <xsl:attribute name="color">white</xsl:attribute>
     <xsl:attribute name="font-weight">bold</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Title-EN" use-attribute-sets="Title">
     <xsl:attribute name="font-family">Candara</xsl:attribute>
     <xsl:attribute name="font-size">30pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Title-JA" use-attribute-sets="Title">
     <!-- Both MS PGothic and MS Gothic blow out.  Try a third-party font. -->
     <xsl:attribute name="font-family">Candara, MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">24pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Title-KO" use-attribute-sets="Title">
     <xsl:attribute name="font-family">Dotum</xsl:attribute>
     <xsl:attribute name="font-size">28pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Blurb">
     <xsl:attribute name="end-indent">5mm</xsl:attribute>
     <xsl:attribute name="padding-right">5mm</xsl:attribute>
     <xsl:attribute name="padding-top">6mm</xsl:attribute>
     <xsl:attribute name="padding-bottom">6mm</xsl:attribute>
     <xsl:attribute name="padding-left"><xsl:value-of select="$margin-left"/></xsl:attribute>
     <xsl:attribute name="margin-bottom">5mm</xsl:attribute>
     <xsl:attribute name="background-color">rgb(153,153,153)</xsl:attribute>
     <xsl:attribute name="color">white</xsl:attribute>
     <xsl:attribute name="font-style">italic</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Blurb-EN" use-attribute-sets="Blurb">
     <xsl:attribute name="font-family">Cambria</xsl:attribute>
     <xsl:attribute name="font-size">16pt</xsl:attribute>
     <xsl:attribute name="line-height">1.7</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Blurb-JA" use-attribute-sets="Blurb">
     <xsl:attribute name="font-family">MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">15pt</xsl:attribute>
     <xsl:attribute name="line-height">1.8</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Blurb-KO" use-attribute-sets="Blurb">
     <xsl:attribute name="font-family">Dotum</xsl:attribute>
     <xsl:attribute name="font-size">14pt</xsl:attribute>
     <xsl:attribute name="line-height">1.8</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Heading1">
     <xsl:attribute name="keep-with-next">always</xsl:attribute>
     <xsl:attribute name="padding-top">2.5mm</xsl:attribute>
     <xsl:attribute name="color"><xsl:value-of select="$basis-blue"/></xsl:attribute>
     <xsl:attribute name="font-weight">bold</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Heading1-EN" use-attribute-sets="Heading1">
     <xsl:attribute name="font-family">Candara</xsl:attribute>
     <xsl:attribute name="font-size">12pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Heading1-JA" use-attribute-sets="Heading1">
     <!-- Both MS PGothic and MS Gothic blow out.  Try a third-party font. -->
     <xsl:attribute name="font-family">MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">13pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Heading1-KO" use-attribute-sets="Heading1">
     <xsl:attribute name="font-family">Dotum</xsl:attribute>
     <xsl:attribute name="font-size">14pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Default-EN">
     <xsl:attribute name="line-height">1.2</xsl:attribute>
     <xsl:attribute name="font-family">Cambria</xsl:attribute>
     <xsl:attribute name="font-size">10pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Default-JA">
     <xsl:attribute name="line-height">1.4</xsl:attribute>
     <xsl:attribute name="font-family">MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">11pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Default-KO">
     <xsl:attribute name="line-height">1.3</xsl:attribute>
     <!-- Batang blows out -->
     <xsl:attribute name="font-family">Gulim</xsl:attribute>
     <xsl:attribute name="font-size">11pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Paragraph">
     <xsl:attribute name="margin-bottom">4mm</xsl:attribute>
     <xsl:attribute name="text-align">justify</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Paragraph-EN" use-attribute-sets="Paragraph Default-EN">
     <xsl:attribute name="orphans">4</xsl:attribute>
     <xsl:attribute name="widows">2</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Paragraph-JA" use-attribute-sets="Paragraph Default-JA">
     <xsl:attribute name="orphans">2</xsl:attribute>
     <xsl:attribute name="widows">1</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Paragraph-KO" use-attribute-sets="Paragraph Default-KO">
     <xsl:attribute name="orphans">2</xsl:attribute>
     <xsl:attribute name="widows">1</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Multicolumn-EN">
     <xsl:attribute name="font-family">Corbel</xsl:attribute>
     <xsl:attribute name="font-size">8pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Multicolumn-JA">
     <xsl:attribute name="font-family">MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">8pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Multicolumn-KO">
     <xsl:attribute name="font-family">Corbel</xsl:attribute>
     <xsl:attribute name="font-size">8pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact1">
     <xsl:attribute name="color"><xsl:value-of select="$basis-blue"/></xsl:attribute>
     <xsl:attribute name="font-weight">bold</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact1-EN" use-attribute-sets="Contact1">
     <xsl:attribute name="font-family">Candara</xsl:attribute>
     <xsl:attribute name="font-size">11pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact1-JA" use-attribute-sets="Contact1">
     <!-- Both MS PGothic and MS Gothic blow out.  Try a third-party font. -->
     <xsl:attribute name="font-family">MS PMincho</xsl:attribute>
     <xsl:attribute name="font-size">12pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact1-KO" use-attribute-sets="Contact1">
     <xsl:attribute name="font-family">Dotum</xsl:attribute>
     <xsl:attribute name="font-size">12pt</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact2">
     <xsl:attribute name="padding-bottom">4mm</xsl:attribute>
     <xsl:attribute name="line-height">0.9</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="Contact2-EN" use-attribute-sets="Contact2 Default-EN"/>
  <xsl:attribute-set name="Contact2-JA" use-attribute-sets="Contact2 Default-JA"/>
  <xsl:attribute-set name="Contact2-KO" use-attribute-sets="Contact2 Default-EN"/>

  <xsl:template match="data-sheet">

     <xsl:message><xsl:value-of select="system-property('xsl:vendor')"/> XSLT <xsl:value-of select="system-property('xsl:version')"/> (page=<xsl:value-of select="$paper-size"/>)</xsl:message>
     <!-- <xsl:message><xsl:value-of select="date:date()"/></xsl:message> -->

     <fo:root>
        <fo:layout-master-set>
           <fo:simple-page-master master-name="front-page" xsl:use-attribute-sets="page-layout">
              <fo:region-body   region-name="front-body"   margin-top="38mm" margin-bottom="13mm" xsl:use-attribute-sets="body-layout" column-count="2"/>
              <fo:region-before region-name="front-before" extent="38mm"/>
              <fo:region-after  region-name="front-after"  extent="8mm" background-color="{$basis-green}"/>
           </fo:simple-page-master>
           <fo:simple-page-master master-name="rear-page" xsl:use-attribute-sets="page-layout">
              <fo:region-body   region-name="rear-body"   margin-top="13mm" margin-bottom="63.5mm" xsl:use-attribute-sets="body-layout" column-count="{@columns}"/>
              <fo:region-before region-name="rear-before" extent="8mm" background-color="{$basis-green}"/>
              <fo:region-after  region-name="rear-after"  extent="63.5mm"/>
           </fo:simple-page-master>
        </fo:layout-master-set>
        <xsl:apply-templates>
           <!-- With XSLT 2.0, can use tunnel="yes" here. -->
           <xsl:with-param name="lang"  select="@lang"/>
           <xsl:with-param name="title" select="@title"/>
        </xsl:apply-templates>
     </fo:root>
  </xsl:template>

  <xsl:template match="front-page">
     <xsl:param name="lang"/>
     <xsl:param name="title"/>
     <fo:page-sequence master-reference="front-page">

        <fo:static-content flow-name="front-before">

           <fo:block-container absolute-position="absolute" height="28.7mm" width="63.5mm" display-align="center">
              <fo:block text-align="center">
                 <fo:external-graphic src="logo.jpg" content-height="0.7in"/>
              </fo:block>
           </fo:block-container>

           <fo:block-container absolute-position="absolute" height="28.7mm" left="63.5mm" display-align="center" background-color="{$basis-blue}">
              <xsl:if test="$lang='EN'">
                 <fo:block xsl:use-attribute-sets="Title-EN">
                    <xsl:value-of select="$title"/>
                 </fo:block>
              </xsl:if>
              <xsl:if test="$lang='JA'">
                 <fo:block xsl:use-attribute-sets="Title-JA">
                    <xsl:value-of select="$title"/>
                 </fo:block>
              </xsl:if>
              <xsl:if test="$lang='KO'">
                 <fo:block xsl:use-attribute-sets="Title-KO">
                    <xsl:value-of select="$title"/>
                 </fo:block>
              </xsl:if>
           </fo:block-container>

           <fo:block-container absolute-position="absolute" top="28.7mm" left="0mm" height="5mm" right="0mm" background-color="{$basis-green}">
              <fo:block/>
           </fo:block-container>

        </fo:static-content>

        <fo:flow flow-name="front-body">
           <xsl:apply-templates>
              <!-- Can remove this when using XSLT 2.0 'tunnel' parameters -->
              <xsl:with-param name="lang" select="$lang"/>
           </xsl:apply-templates>
        </fo:flow>

     </fo:page-sequence>
  </xsl:template>

  <xsl:template match="rear-page">
     <xsl:param name="lang"/>
     <fo:page-sequence master-reference="rear-page">

        <fo:static-content flow-name="rear-after">

           <fo:block-container absolute-position="absolute" top="0in" left="{$margin-left}" right="{$margin-right}">

              <!-- border-bottom-width=0.05pt -->
              <fo:block text-align="justify" border-bottom-style="solid" border-bottom-width="medium" padding-bottom="0.10in" margin-bottom="0.15in"
                       font-family="Cambria" font-size="8pt">
                 &legal-notices;
              </fo:block>

              <fo:table table-layout="fixed" width="100%">
                 <fo:table-column column-width="2.4in"/>
                 <fo:table-column column-width="2.1in"/>
                 <fo:table-column column-width="3.1in"/>
                 <fo:table-body>
                    <fo:table-row>
                       <fo:table-cell display-align="center">
                          <fo:block>
                             <fo:external-graphic src="logo.jpg" content-height="0.7in"/>
                          </fo:block>
                       </fo:table-cell>
                       <xsl:if test="$lang='EN'">
                          <xsl:call-template name="contact-EN"/>
                       </xsl:if>
                       <xsl:if test="$lang='JA'">
                          <xsl:call-template name="contact-JA"/>
                       </xsl:if>
                       <xsl:if test="$lang='KO'">
                          <xsl:call-template name="contact-KO"/>
                       </xsl:if>
                    </fo:table-row>
                 </fo:table-body>
              </fo:table>

           </fo:block-container>

           <fo:block-container absolute-position="absolute" height="8mm" top="55mm" background-color="{$basis-green}">
              <fo:block/>
           </fo:block-container>

        </fo:static-content>

        <fo:flow flow-name="rear-body">
           <xsl:apply-templates>
              <!-- We need the XSLT 2.0 'tunnel' parameters so we don't need to keep passing this down -->
              <xsl:with-param name="lang" select="$lang"/>
           </xsl:apply-templates>
        </fo:flow>

     </fo:page-sequence>
  </xsl:template>

  <xsl:template match="blurb">
     <xsl:param name="lang"/>
     <xsl:if test="$lang='EN'">
        <fo:block xsl:use-attribute-sets="Blurb-EN">
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='JA'">
        <fo:block xsl:use-attribute-sets="Blurb-JA">
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='KO'">
        <fo:block xsl:use-attribute-sets="Blurb-KO">
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
  </xsl:template>

  <xsl:template match="p">
     <xsl:param name="lang"/>
     <xsl:if test="$lang='EN'">
        <fo:block xsl:use-attribute-sets="Paragraph-EN">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='JA'">
        <fo:block xsl:use-attribute-sets="Paragraph-JA">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='KO'">
        <fo:block xsl:use-attribute-sets="Paragraph-KO">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
  </xsl:template>

  <xsl:template match="h1">
     <xsl:param name="lang"/>
     <xsl:if test="$lang='EN'">
        <fo:block xsl:use-attribute-sets="Heading1-EN">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='JA'">
        <fo:block xsl:use-attribute-sets="Heading1-JA">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
     <xsl:if test="$lang='KO'">
        <fo:block xsl:use-attribute-sets="Heading1-KO">
           <xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
           <xsl:apply-templates/>
        </fo:block>
     </xsl:if>
  </xsl:template>

  <!-- This screws up windows and orphans formatting.  Need 'keep-with-next'  -->
  <xsl:template match="br">
     <fo:block keep-with-previous="always" keep-with-next="always"/>
  </xsl:template>

  <xsl:template match="example">
     <fo:block line-height="1.3" padding-bottom="0.15in" margin-left="0.3in" font-family="Corbel" font-size="9pt">
        <xsl:apply-templates/>
     </fo:block>
  </xsl:template>

  <xsl:template match="example-rtl">
     <!-- This reverses the direction of the characters as well -->
     <fo:block-container writing-mode="rl">
        <fo:block line-height="1.0" padding-bottom="0.15in" margin-left="0.3in" font-family="Scheherazade" font-size="12pt">
           <xsl:apply-templates/>
        </fo:block>
     </fo:block-container>
  </xsl:template>

  <xsl:template match="graphic">
     <xsl:variable name="floating"><xsl:value-of select="@floating"/></xsl:variable>
     <xsl:choose>
        <!-- Floating graphic -->
        <xsl:when test="$floating='yes'">
           <fo:block-container absolute-position="absolute">
              <xsl:attribute name="left"><xsl:value-of select="@left"/></xsl:attribute>
              <xsl:attribute name="top"><xsl:value-of select="@top"/></xsl:attribute>
              <fo:block>
                 <fo:external-graphic background-color="rgb(240,240,240)" border="black solid 0.5pt" padding="2pt">
                    <xsl:attribute name="content-width"><xsl:value-of select="@content-width"/></xsl:attribute>
                    <xsl:attribute name="src">Examples/<xsl:value-of select="@name"/>.gif</xsl:attribute>
                 </fo:external-graphic>
              </fo:block>
           </fo:block-container>
        </xsl:when>
        <!-- Inline graphic -->
        <xsl:otherwise>
           <fo:block margin-bottom="0.15in">
              <fo:external-graphic content-width="3.4in" border="black solid 0.5pt" padding="2pt">
                 <xsl:attribute name="src">Examples/<xsl:value-of select="@name"/>.gif</xsl:attribute>
              </fo:external-graphic>
           </fo:block>
        </xsl:otherwise>
     </xsl:choose>
  </xsl:template>

  <xsl:template match="ul">
     <xsl:param name="lang"/>
     <xsl:if test="$lang='EN'">
        <fo:list-block start-indent="5mm" padding-bottom="8pt" xsl:use-attribute-sets="Default-EN">
           <xsl:apply-templates/>
        </fo:list-block>
     </xsl:if>
     <xsl:if test="$lang='JA'">
        <fo:list-block start-indent="5mm" padding-bottom="8pt" xsl:use-attribute-sets="Default-JA">
           <xsl:apply-templates/>
        </fo:list-block>
     </xsl:if>
     <xsl:if test="$lang='KO'">
        <fo:list-block start-indent="5mm" padding-bottom="8pt" xsl:use-attribute-sets="Default-KO">
           <xsl:apply-templates/>
        </fo:list-block>
     </xsl:if>
  </xsl:template>

  <xsl:template match="ul/li">
     <fo:list-item keep-with-previous="always">
        <fo:list-item-label>
           <fo:block>&bullet;</fo:block>
        </fo:list-item-label>
        <fo:list-item-body start-indent="9mm">
           <fo:block>
              <xsl:apply-templates/>
           </fo:block>
        </fo:list-item-body>
     </fo:list-item>
  </xsl:template>

  <xsl:template match="multicolumn">
     <xsl:param name="lang"/>
     <xsl:variable name="width"><xsl:value-of select="@width"/></xsl:variable>
     <xsl:variable name="bullets"><xsl:value-of select="@bullets"/></xsl:variable>
     <fo:table table-layout="fixed" margin-bottom="0.15in">
        <xsl:attribute name="width">
           <xsl:choose>
              <xsl:when test="string-length($width)=0">100%</xsl:when>
              <xsl:otherwise>
                 <xsl:value-of select="$width"/>
              </xsl:otherwise>
           </xsl:choose>
        </xsl:attribute>
        <xsl:if test="$bullets='yes'">
           <xsl:attribute name="start-indent">5mm</xsl:attribute>
        </xsl:if>
        <fo:table-body>
           <xsl:if test="$lang='EN'">
              <fo:table-row xsl:use-attribute-sets="Multicolumn-EN">
                 <xsl:apply-templates>
                    <xsl:with-param name="bullets" select="$bullets"/>
                 </xsl:apply-templates>
              </fo:table-row>
           </xsl:if>
           <xsl:if test="$lang='JA'">
              <fo:table-row xsl:use-attribute-sets="Multicolumn-JA">
                 <xsl:apply-templates>
                    <xsl:with-param name="bullets" select="$bullets"/>
                 </xsl:apply-templates>
              </fo:table-row>
           </xsl:if>
           <xsl:if test="$lang='KO'">
              <fo:table-row xsl:use-attribute-sets="Multicolumn-KO">
                 <xsl:apply-templates>
                    <xsl:with-param name="bullets" select="$bullets"/>
                 </xsl:apply-templates>
              </fo:table-row>
           </xsl:if>
        </fo:table-body>
     </fo:table>
  </xsl:template>

  <xsl:template match="column">
     <xsl:param name="bullets"/>
     <fo:table-cell>
        <fo:list-block>
           <xsl:apply-templates>
              <xsl:with-param name="bullets" select="$bullets"/>
           </xsl:apply-templates>
        </fo:list-block>
     </fo:table-cell>
  </xsl:template>

  <xsl:template match="column/li">
     <xsl:param name="bullets"/>
     <fo:list-item>
        <fo:list-item-label>
           <xsl:choose>
              <xsl:when test="$bullets='yes'">
                 <fo:block>&bullet;</fo:block>
              </xsl:when>
              <xsl:otherwise>
                 <fo:block/>
              </xsl:otherwise>
           </xsl:choose>
        </fo:list-item-label>
        <fo:list-item-body>
           <xsl:if test="$bullets='yes'">
              <xsl:attribute name="start-indent">8mm</xsl:attribute>
           </xsl:if>
           <fo:block>
              <xsl:apply-templates/>
           </fo:block>
        </fo:list-item-body>
     </fo:list-item>
  </xsl:template>

  <xsl:template match="table-example">
  </xsl:template>

  <xsl:template match="b">
     <fo:inline font-weight="bold">
        <xsl:apply-templates/>
     </fo:inline>
  </xsl:template>

  <xsl:template match="i">
     <fo:inline font-style="italic">
        <xsl:apply-templates/>
     </fo:inline>
  </xsl:template>

  <xsl:template match="em">
     <fo:inline font-style="italic" font-weight="bold">
        <xsl:apply-templates/>
     </fo:inline>
  </xsl:template>

  <xsl:template match="a">
     <fo:inline text-decoration="underline" color="blue">
        <xsl:apply-templates/>
     </fo:inline>
  </xsl:template>

  <xsl:template match="sup">
     <fo:inline font-size="0.75em" baseline-shift="super">
        <xsl:apply-templates/>
     </fo:inline>
  </xsl:template>

  <xsl:template match="reg">
     <fo:character character="®"/>
  </xsl:template>

  <xsl:template match="nobr">
     <fo:block linefeed-treatment="treat-as-space">
        <fo:wrapper wrap-option="no-wrap">
           <xsl:apply-templates/>
        </fo:wrapper>
     </fo:block>
  </xsl:template>

  <xsl:template name="contact-EN">
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-EN">Browse</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">www.basistech.com</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-EN">Write</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">info&year;@basistech.com</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-EN">Call</fo:block>
        <!-- For US letter data sheet, use 617-386-2090 and 800-697-2062 -->
        <!-- For international A4 data sheet, use +1-617-386-2090 -->
        <fo:block xsl:use-attribute-sets="Contact2-EN">
           <xsl:if test="$paper-size='letter'">617-386-2090 or 800-697-2062</xsl:if>
           <xsl:if test="$paper-size='A4'">+1-617-386-2090</xsl:if>
        </fo:block>
     </fo:table-cell>
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-EN">Boston</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">One Alewife Center, Cambridge, MA 02140</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-EN">San Francisco</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">171 Second Street, San Francisco, CA 94105</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-EN">Washington, D.C.</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">13800 Coppermine Road, Herndon, VA 20171</fo:block>
     </fo:table-cell>
  </xsl:template>

  <xsl:template name="contact-JA">
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-JA">詳細</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">www.basistech.jp</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-JA">お問合せ</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">info&year;@basistech.jp</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-JA">電話番号</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">03-3511-2947</fo:block>
     </fo:table-cell>
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-JA">ベイシス・テクノロジー株式会社</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-JA">〒102-0084東京都千代田区二番町9-6</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-JA">ボストン本社</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">One Alewife Center, Cambridge, MA 02140</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-JA">ワシントンD.C.支社</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-EN">13800 Coppermine Road, Herndon, VA 20171</fo:block>
     </fo:table-cell>
  </xsl:template>

  <xsl:template name="contact-KO">
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-KO">URL</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">www.basistech.co.kr</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-KO">e-메일</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">info&year;@basistech.com</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-KO">전화번호 (일본지사)</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">+81-3-3511-2947</fo:block>
     </fo:table-cell>
     <fo:table-cell>
        <fo:block xsl:use-attribute-sets="Contact1-KO">일본 지사 (동경)</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">9-6 Nibancho, Chiyoda-ku, Tokyo 102-0084</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-KO">미국 본사 (보스턴)</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">One Alewife Center, Cambridge, MA 02140</fo:block>
        <fo:block xsl:use-attribute-sets="Contact1-KO">워싱턴 지사 (워싱턴 D.C)</fo:block>
        <fo:block xsl:use-attribute-sets="Contact2-KO">13800 Coppermine Road, Herndon, VA 20171</fo:block>
     </fo:table-cell>
  </xsl:template>

</xsl:stylesheet>
